<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet xmlns:xsl="http://www.w3.org/1999/XSL/Transform" 
      xmlns:xs="http://www.w3.org/2001/XMLSchema"
      xmlns:inter="http://www.mitre.org/ocil/2"
      exclude-result-prefixes="xs"
      version="2.0">

    <xsl:output method="html"/>

    <xsl:key name="questionnaire_id"
        match="//inter:questionnaire" use="@id"/>
    <xsl:key name="questionnarie_child"
        match="//inter:questionnaire" use="@child_only"/>
    
    <xsl:key name="question_test_action_id" match="//inter:boolean_question_test_action|//inter:choice_question_test_action|//inter:numeric_question_test_action|//inter:string_question_test_action"
        use="@id"/>
    <xsl:key name="question_id" match="//inter:boolean_question|//inter:choice_question|//inter:numeric_question|//inter:string_question"
        use="@id"/>
   
    <xsl:key name="qres" match="//inter:questionnaire_result" use="@questionnaire_ref" />
    <xsl:key name="tres" match="//inter:test_action_result"
        use="@test_action_ref"/>
    <xsl:key name="qtres" match="//inter:boolean_question_result|//inter:numeric_question_result|//inter:string_question_result"
        use="@question_ref"/>
     <xsl:key name="qcres" match="//inter:choice_question_result"
        use="@question_ref"/>


    <xsl:template match="/">        
        <html>
            <head>
                <link href="results.css" type="text/css" rel="stylesheet"/>
                <title>OCIL Documento de resultados</title>
            </head>
            <body>
                <xsl:apply-templates select="//inter:ocil" />                
            </body>
        </html>        
    </xsl:template>
    
    <xsl:template match="//inter:ocil">
        <h1>GT-SCHEMA RedIRIS <img src="RedIRIS.png" alt="RedIRIS" align="center" /> </h1>
            
        <xsl:apply-templates select="//inter:generator" />
        <xsl:apply-templates select="//inter:document" /> 
        <xsl:apply-templates select="//inter:results" />
        <xsl:apply-templates select="//inter:questionnaires" />
    </xsl:template>

    <xsl:template match="//inter:generator">
        <h2>Generador</h2>
        <table>
            <tr><th>Campo</th><th>Valor</th></tr>
            <xsl:for-each select="*">
                <xsl:choose>
                    <xsl:when test="local-name(.)='author'">
                        <tr>
                            <td>author</td>
                            <td><xsl:for-each select="./*"><xsl:value-of select="." /> ; </xsl:for-each></td>
                        </tr>
                    </xsl:when>
                    <xsl:otherwise>
                        <tr><td><xsl:value-of select="local-name(.)" /></td><td><xsl:value-of select="." /></td></tr>
                    </xsl:otherwise>
                </xsl:choose>
            </xsl:for-each>            
        </table>
    </xsl:template>
    
    <xsl:template match="//inter:document">
        <h2>Documento</h2>
        <table>
            <tr><th>Campo</th><th>Valor</th></tr>
            <xsl:for-each select="*">
                <tr><td><xsl:value-of select="local-name(.)" /></td><td><xsl:value-of select="." /></td></tr>
            </xsl:for-each>            
        </table>
    </xsl:template>
    
    <xsl:template match="//inter:results">
        <h2>Resultado de los questionarios</h2>        
        
    </xsl:template>

    <xsl:template match="//inter:questionnaires">            
                <xsl:apply-templates select="//inter:questionnaire" />          
    </xsl:template>

    <xsl:template  match="//inter:questionnaire">      
      <xsl:param name="hijo" />
      <xsl:param name="numref" select="substring(@id,32)" />
      <div class="questionario">
      <xsl:choose>
        <xsl:when test='$hijo != "ok" and $numref &gt; 20'></xsl:when>
        <xsl:otherwise><br />
         <table><tr><td>
            <xsl:apply-templates select="key('qres', @id)" /> 		        
	        </td>
	        <td><b> <xsl:value-of select="./inter:title" /> &#160;</b> <xsl:value-of select="./inter:description" />	</td>
	        </tr>
          <tr><td> </td><td>
	        <ul> 
	        <xsl:for-each select="./inter:actions/inter:test_action_ref" >
		        <xsl:apply-templates select="key('question_test_action_id' , .)" />
		        <xsl:apply-templates select="key('questionnaire_id' , .)" >
                  <xsl:with-param name="hijo"  select='"ok"' />
            </xsl:apply-templates>             
		        <br />                 
	        </xsl:for-each>          
          </ul>
          </td></tr></table>
	        
        </xsl:otherwise>
      </xsl:choose>
      </div>
    </xsl:template>

    <xsl:template match="//inter:boolean_question_test_action|//inter:choice_question_test_action|//inter:numeric_question_test_action|//inter:string_question_test_action" >
          <xsl:apply-templates select="key('tres', @id)" />
          <xsl:apply-templates select="key('question_id',@question_ref)" /> <br />
        
    </xsl:template>
    
    <xsl:template match="//inter:boolean_question|//inter:choice_question|//inter:numeric_question|//inter:string_question" >
      <span class="question"><xsl:value-of select="./inter:question_text" /></span>
      <span class="res"><xsl:apply-templates select="key('qtres', @id)" /></span>
	    <span class="res"><xsl:apply-templates select="key('qcres', @id)" /></span>
    </xsl:template>
    
    <xsl:template match="//inter:questionnaire_result">
        <xsl:variable name="qnid" select="@questionnaire_ref"/>
        <xsl:variable name="qnres" select="@result"/>
        <xsl:variable name="qn" select="key('questionnaire_id', $qnid)" />
        <xsl:variable name="qntitle" select="$qn/inter:title"/>
        <xsl:variable name="qndesc" select="$qn/inter:description"/>
        <xsl:choose>
          <xsl:when test="$qnres='PASS'"> 
							<span class="res_pass" > 
					         <img src="pass.png" alt="pass" align="center" />
							</span>
					</xsl:when>
          <xsl:when test="$qnres='FAIL'"> 
              <span class="res_fail" > 
                   <img src="fail.png" alt="fail" align="center" />
              </span>
          </xsl:when>							
          <xsl:otherwise>
              <span class="res_not_tested" > 
                   <img src="not_tested.png" alt="fail" align="center" />
              </span>
           </xsl:otherwise>
          
        </xsl:choose>
    </xsl:template>

    <xsl:template match="//inter:test_action_result">
        <xsl:variable name="taid" select="@test_action_ref"/>
        <xsl:variable name="tares" select="@result"/>
        <xsl:variable name="ta" select="key('question_test_action_id', $taid)" />
        <xsl:variable name="tatitle" select="$ta/inter:title"/>
        <xsl:variable name="tadesc" select="$ta/inter:description"/>
       		

        <xsl:choose>
          <xsl:when test="$tares='PASS'"> 
              <li class="li_pass" > 
                   &#160;<b><xsl:value-of select="$tatitle"/></b>
              </li>
          </xsl:when>
          <xsl:when test="$tares='FAIL'"> 
              <li class="li_fail" > 
                   &#160;<b><xsl:value-of select="$tatitle"/></b>
              </li>
          </xsl:when>             
          <xsl:otherwise>
              <li class="li_not_tested" > 
                   &#160;<b><xsl:value-of select="$tatitle"/></b>
              </li>
           </xsl:otherwise>
          
        </xsl:choose>
       
    </xsl:template>
   
    <xsl:template match="//inter:boolean_question_result|//inter:numeric_question_result|//inter:string_question_result">
        <xsl:variable name="question_id" select="@question_ref"/>
        <xsl:variable name="question_answer" select="./inter:answer"/>
        <xsl:variable name="question_response" select="@response"/>
        <xsl:variable name="question" select="key('question_id', $question_id)" />
        <xsl:variable name="question_text" select="$question/inter:question_text"/>
        
                <xsl:if test="$question_response='ANSWERED'">
                    &#160;<xsl:value-of select="$question_answer"/>                    
                </xsl:if>
                <xsl:if test="$question_response!='ANSWERED'">
                    &#160;<xsl:value-of select="$question_response"/>                    
                </xsl:if>
            
    </xsl:template>
 
    <xsl:template match="//inter:choice_question_result">
        <xsl:variable name="question_id" select="@question_ref"/>
        <xsl:variable name="question_choice_ref" select="//inter:answer/@choice_ref"/>
        <xsl:variable name="question_response" select="@response"/>
        <xsl:variable name="question" select="key('question_id', $question_id)" />
        <xsl:variable name="question_answer" select="$question/inter:choice[@id=$question_choice_ref]"/>
        <xsl:variable name="question_text" select="$question/inter:question_text"/>
        
                <xsl:if test="$question_response='PASS'">
                   &#160;<xsl:value-of select="$question_answer"/>                    
                </xsl:if>
                <xsl:if test="$question_response!='PASS'">
                    &#160;<xsl:value-of select="$question_response"/>                    
                </xsl:if>
            
    </xsl:template>

</xsl:stylesheet>
